from rich.console import Console

CONSOLE = Console()
BASE_URL_ACCOUNT = "https://account.jaye.world"
BASE_URL_PUBLIC = "https://qaas.jaye.world"
